diff --git a/core/lib/Drupal/Core/Entity/Query/QueryAggregateInterface.php b/core/lib/Drupal/Core/Entity/Query/QueryAggregateInterface.php
index 0109fdeed01dd93106af8e1199200a4712aed60c..f553b8a519c62a1efc33eec0c0c894bfeded2501 100644
--- a/core/lib/Drupal/Core/Entity/Query/QueryAggregateInterface.php
+++ b/core/lib/Drupal/Core/Entity/Query/QueryAggregateInterface.php
@@ -140,7 +140,7 @@ public function sortAggregate($field, $function, $direction = 'ASC', $langcode =
    *     $result = $query
    *       ->aggregate('nid', 'count')
    *       ->condition('status', 1)
-   *       ->groupby('type')
+   *       ->groupBy('type')
    *       ->execute();
    *   @endcode
    *   Will return:
diff --git a/core/lib/Drupal/Core/Entity/Query/Sql/QueryAggregate.php b/core/lib/Drupal/Core/Entity/Query/Sql/QueryAggregate.php
index fd257ab69390e58a0562be896bfcf9c5082bd257..96a5253027a79a4c3fe10ff49f5646bced995acd 100644
--- a/core/lib/Drupal/Core/Entity/Query/Sql/QueryAggregate.php
+++ b/core/lib/Drupal/Core/Entity/Query/Sql/QueryAggregate.php
@@ -94,7 +94,7 @@ protected function compileAggregate() {
   }
 
   /**
-   * Adds the groupby values to the actual query.
+   * Adds the group by values to the actual query.
    *
    * @return $this
    *   Returns the called object.
diff --git a/core/misc/cspell/dictionary.txt b/core/misc/cspell/dictionary.txt
index dc36ea926be5fed949691391c4597e1f62c7902f..3345cef81289d2e762b7aa6bc532d0050369f425 100644
--- a/core/misc/cspell/dictionary.txt
+++ b/core/misc/cspell/dictionary.txt
@@ -10,7 +10,6 @@ ajaxing
 allwords
 alphadecimal
 ampm
-anyall
 archiver
 archivers
 arrowrefresh
@@ -31,7 +30,6 @@ autoloaders
 autoloading
 autop
 autoplace
-autoplay
 autoreply
 autosubmit
 backlink
@@ -137,7 +135,6 @@ csslintrc
 csstools
 cweagans
 datelist
-daterange
 datestamp
 datetimeiso
 datetimeplus
@@ -222,7 +219,6 @@ fcgi
 fdiv
 fieldable
 fieldapi
-fieldblock
 fieldgroup
 fieldgroups
 fieldnames
@@ -245,7 +241,6 @@ fraƮche
 frontpage
 fudgy
 fulldata
-fulldate
 fulltext
 gabilondo
 gids
@@ -253,8 +248,6 @@ gloop
 greeking
 gripsmall
 groupable
-groupby
-groupwise
 guzzlehttp
 hande
 hateoas
@@ -282,7 +275,6 @@ introspectable
 invalidators
 invokable
 isam
-itok
 javascripts
 jessebeach
 jqueryui
@@ -437,7 +429,6 @@ prepopulating
 prepopulation
 preprocesses
 preprocessors
-prerender
 prerendered
 presave
 pretransaction
@@ -506,7 +497,6 @@ shorterthan
 shortlink
 singlebyte
 sirbrillig
-sitename
 sitewide
 slatkin
 smacss
@@ -553,7 +543,6 @@ subproject
 subprojects
 subproperties
 subqueries
-subquery
 subrequest
 subrequest's
 subrequests
@@ -635,7 +624,6 @@ uninstallations
 unmanaged
 unminified
 unmoderated
-unpromote
 unpublish
 unpublishes
 unpublishing
@@ -648,7 +636,6 @@ unserializes
 unserializing
 unsets
 unsetting
-unsticky
 untabbable
 upcasted
 upcasting
diff --git a/core/misc/cspell/drupal-dictionary.txt b/core/misc/cspell/drupal-dictionary.txt
index 4127b2fb89a06c060de4d4bff7ec64bc87e3c63b..7fcd695aa613342a5606337422fdb350901c03b7 100644
--- a/core/misc/cspell/drupal-dictionary.txt
+++ b/core/misc/cspell/drupal-dictionary.txt
@@ -1,5 +1,6 @@
 bartik
 corepack
+daterange
 dblog
 dependee
 dependee's
@@ -8,6 +9,7 @@ drupalci
 drupalimage
 druplicon
 drush
+groupwise
 jswebassert
 langcode
 langcodes
@@ -16,9 +18,14 @@ mulrev
 mulrevpub
 olivero
 olivero's
+prerender
 revlog
 revpub
 simpletest
+sitename
+subquery
 tempstore
 umami
+unpromote
+unsticky
 validatable
diff --git a/core/modules/comment/src/CommentViewsData.php b/core/modules/comment/src/CommentViewsData.php
index 944827366376f987c3612857763e0a71e6e57d5c..904ef132d49493fad5c81b88e926aabe0fde4a88 100644
--- a/core/modules/comment/src/CommentViewsData.php
+++ b/core/modules/comment/src/CommentViewsData.php
@@ -5,6 +5,8 @@
 use Drupal\Core\Entity\ContentEntityInterface;
 use Drupal\views\EntityViewsData;
 
+// cspell:ignore fulldate
+
 /**
  * Provides views data for the comment entity type.
  */
diff --git a/core/modules/file/config/schema/file.schema.yml b/core/modules/file/config/schema/file.schema.yml
index d8b098d50fc2b990a26701f7412f41bd152d0421..e193063740b7334830647433466f0f78c2b2c2b6 100644
--- a/core/modules/file/config/schema/file.schema.yml
+++ b/core/modules/file/config/schema/file.schema.yml
@@ -1,4 +1,5 @@
 # Schema for the configuration files of the File module.
+# cspell:ignore autoplay
 
 file.settings:
   type: config_object
diff --git a/core/modules/image/config/install/image.settings.yml b/core/modules/image/config/install/image.settings.yml
index c92db4e155f43cc5a44f189ed8db494d33d2b90a..d7a86b5cda94658aac89994169b2b75d6f26d808 100644
--- a/core/modules/image/config/install/image.settings.yml
+++ b/core/modules/image/config/install/image.settings.yml
@@ -1,3 +1,4 @@
+# cspell:ignore itok
 preview_image: core/modules/image/sample.png
 allow_insecure_derivatives: false
 suppress_itok_output: false
diff --git a/core/modules/image/config/schema/image.schema.yml b/core/modules/image/config/schema/image.schema.yml
index f805caa378ca822067e3fb36ddf1f9fe43a412b6..282be146db6e7c96ce6505e49a28c90bf8c9f881 100644
--- a/core/modules/image/config/schema/image.schema.yml
+++ b/core/modules/image/config/schema/image.schema.yml
@@ -1,4 +1,5 @@
 # Schema for configuration files of the Image module.
+# cspell:ignore itok
 
 image.style.*:
   type: config_entity
diff --git a/core/modules/image/image.admin.inc b/core/modules/image/image.admin.inc
index 73b7ffdf9e1008b38e5b57984df6cb99615dbc58..c5ef0f6a3f65faba4250e3b09d8ee55b470ec5ce 100644
--- a/core/modules/image/image.admin.inc
+++ b/core/modules/image/image.admin.inc
@@ -7,6 +7,8 @@
 
 use Drupal\Core\Render\Element;
 
+// cspell:ignore itok
+
 /**
  * Prepares variables for image style preview templates.
  *
diff --git a/core/modules/image/image.module b/core/modules/image/image.module
index 0d8bd4b1f265a84c3e2e170787c2343e8aef8f1d..afe4b1f8f72fbcb84ede68c18b0a88365733eb1b 100644
--- a/core/modules/image/image.module
+++ b/core/modules/image/image.module
@@ -16,6 +16,8 @@
 use Drupal\image\Controller\ImageStyleDownloadController;
 use Drupal\image\Entity\ImageStyle;
 
+// cspell:ignore itok
+
 /**
  * The name of the query parameter for image derivative tokens.
  */
diff --git a/core/modules/image/migrations/d7_image_settings.yml b/core/modules/image/migrations/d7_image_settings.yml
index e5aec79a827d8eed8848b3d36032187a25afd497..da3be1022cb4b3cb9d588d60117a2d8a2192fe58 100644
--- a/core/modules/image/migrations/d7_image_settings.yml
+++ b/core/modules/image/migrations/d7_image_settings.yml
@@ -1,3 +1,4 @@
+# cspell:ignore itok
 id: d7_image_settings
 label: Image configuration
 migration_tags:
diff --git a/core/modules/image/src/Entity/ImageStyle.php b/core/modules/image/src/Entity/ImageStyle.php
index f975dc10932c30f221464262830c2bb7c79c9e95..7b0f8b3eeccf577d3e02203ccbac6dbe304475d7 100644
--- a/core/modules/image/src/Entity/ImageStyle.php
+++ b/core/modules/image/src/Entity/ImageStyle.php
@@ -24,6 +24,8 @@
 use Symfony\Component\DependencyInjection\Exception\ServiceNotFoundException;
 use Drupal\Core\Entity\Entity\EntityViewDisplay;
 
+// cspell:ignore itok
+
 /**
  * Defines an image style configuration entity.
  *
diff --git a/core/modules/image/tests/src/Functional/ImageAdminStylesTest.php b/core/modules/image/tests/src/Functional/ImageAdminStylesTest.php
index 9b3a3106333fcd704cb57de9472f9dc256f7cf4f..ecd21004d4430cf08e51abe7434cfdc0279c9c37 100644
--- a/core/modules/image/tests/src/Functional/ImageAdminStylesTest.php
+++ b/core/modules/image/tests/src/Functional/ImageAdminStylesTest.php
@@ -12,6 +12,8 @@
 use Drupal\node\Entity\Node;
 use Drupal\Tests\TestFileCreationTrait;
 
+// cspell:ignore itok
+
 /**
  * Tests creation, deletion, and editing of image styles and effects.
  *
diff --git a/core/modules/image/tests/src/Functional/ImageStyleDownloadAccessControlTest.php b/core/modules/image/tests/src/Functional/ImageStyleDownloadAccessControlTest.php
index c1d17b1b379e8cc1f438b66b4804adb9b722a935..ba2e840882eb8f1f81cd853fef2c1540d9afb424 100644
--- a/core/modules/image/tests/src/Functional/ImageStyleDownloadAccessControlTest.php
+++ b/core/modules/image/tests/src/Functional/ImageStyleDownloadAccessControlTest.php
@@ -10,6 +10,8 @@
 use Drupal\image\Entity\ImageStyle;
 use Drupal\Tests\BrowserTestBase;
 
+// cspell:ignore itok
+
 /**
  * Tests access control for downloading image styles.
  *
diff --git a/core/modules/image/tests/src/Functional/ImageStylesPathAndUrlTest.php b/core/modules/image/tests/src/Functional/ImageStylesPathAndUrlTest.php
index 25e753b9ed8b0020c4840b542af7f8935621b203..c66fe061e5687fb4a2b6b10dc678d6dcd38c37b7 100644
--- a/core/modules/image/tests/src/Functional/ImageStylesPathAndUrlTest.php
+++ b/core/modules/image/tests/src/Functional/ImageStylesPathAndUrlTest.php
@@ -12,6 +12,8 @@
 use Drupal\Tests\BrowserTestBase;
 use Drupal\Tests\TestFileCreationTrait;
 
+// cspell:ignore itok
+
 /**
  * Tests the functions for generating paths and URLs for image styles.
  *
diff --git a/core/modules/layout_builder/tests/modules/layout_builder_fieldblock_test/config/schema/layout_builder_fieldblock_test.schema.yml b/core/modules/layout_builder/tests/modules/layout_builder_field_block_test/config/schema/layout_builder_field_block_test.schema.yml
similarity index 52%
rename from core/modules/layout_builder/tests/modules/layout_builder_fieldblock_test/config/schema/layout_builder_fieldblock_test.schema.yml
rename to core/modules/layout_builder/tests/modules/layout_builder_field_block_test/config/schema/layout_builder_field_block_test.schema.yml
index 92ce34d00634ce13b6c767550262c9364a1553ee..18b4fa8d40285f0218c727a99c89824b444e28da 100644
--- a/core/modules/layout_builder/tests/modules/layout_builder_fieldblock_test/config/schema/layout_builder_fieldblock_test.schema.yml
+++ b/core/modules/layout_builder/tests/modules/layout_builder_field_block_test/config/schema/layout_builder_field_block_test.schema.yml
@@ -1,3 +1,3 @@
-# See \Drupal\layout_builder_fieldblock_test\Plugin\Block\FieldBlock.
+# See \Drupal\layout_builder_field_block_test\Plugin\Block\FieldBlock.
 block.settings.field_block_test:*:*:*:
   type: block.settings.field_block:*:*:*
diff --git a/core/modules/layout_builder/tests/modules/layout_builder_fieldblock_test/layout_builder_fieldblock_test.info.yml b/core/modules/layout_builder/tests/modules/layout_builder_field_block_test/layout_builder_field_block_test.info.yml
similarity index 100%
rename from core/modules/layout_builder/tests/modules/layout_builder_fieldblock_test/layout_builder_fieldblock_test.info.yml
rename to core/modules/layout_builder/tests/modules/layout_builder_field_block_test/layout_builder_field_block_test.info.yml
diff --git a/core/modules/layout_builder/tests/modules/layout_builder_field_block_test/layout_builder_field_block_test.services.yml b/core/modules/layout_builder/tests/modules/layout_builder_field_block_test/layout_builder_field_block_test.services.yml
new file mode 100644
index 0000000000000000000000000000000000000000..3b4933f2dc2fe2fb8ffa05e9ea6c6273b38ba2cc
--- /dev/null
+++ b/core/modules/layout_builder/tests/modules/layout_builder_field_block_test/layout_builder_field_block_test.services.yml
@@ -0,0 +1,5 @@
+services:
+  layout_builder_field_block_test.fake_view_mode_context:
+    class: Drupal\layout_builder_field_block_test\ContextProvider\FakeViewModeContext
+    tags:
+      - { name: 'context_provider' }
diff --git a/core/modules/layout_builder/tests/modules/layout_builder_fieldblock_test/src/ContextProvider/FakeViewModeContext.php b/core/modules/layout_builder/tests/modules/layout_builder_field_block_test/src/ContextProvider/FakeViewModeContext.php
similarity index 90%
rename from core/modules/layout_builder/tests/modules/layout_builder_fieldblock_test/src/ContextProvider/FakeViewModeContext.php
rename to core/modules/layout_builder/tests/modules/layout_builder_field_block_test/src/ContextProvider/FakeViewModeContext.php
index a6558cacc026c628443f8e240baafde6a9268e3e..d22fd9c096acedc3ce1903dd59031cf9aab9ebcd 100644
--- a/core/modules/layout_builder/tests/modules/layout_builder_fieldblock_test/src/ContextProvider/FakeViewModeContext.php
+++ b/core/modules/layout_builder/tests/modules/layout_builder_field_block_test/src/ContextProvider/FakeViewModeContext.php
@@ -2,7 +2,7 @@
 
 declare(strict_types=1);
 
-namespace Drupal\layout_builder_fieldblock_test\ContextProvider;
+namespace Drupal\layout_builder_field_block_test\ContextProvider;
 
 use Drupal\Core\Plugin\Context\Context;
 use Drupal\Core\Plugin\Context\ContextDefinition;
diff --git a/core/modules/layout_builder/tests/modules/layout_builder_fieldblock_test/src/Plugin/Block/FieldBlock.php b/core/modules/layout_builder/tests/modules/layout_builder_field_block_test/src/Plugin/Block/FieldBlock.php
similarity index 93%
rename from core/modules/layout_builder/tests/modules/layout_builder_fieldblock_test/src/Plugin/Block/FieldBlock.php
rename to core/modules/layout_builder/tests/modules/layout_builder_field_block_test/src/Plugin/Block/FieldBlock.php
index 3f99c11cac021e2719d9796984a22e2a83b41375..1ad52a5b1db6ad3b7b8524de1eabc11d0e28d0a7 100644
--- a/core/modules/layout_builder/tests/modules/layout_builder_fieldblock_test/src/Plugin/Block/FieldBlock.php
+++ b/core/modules/layout_builder/tests/modules/layout_builder_field_block_test/src/Plugin/Block/FieldBlock.php
@@ -2,7 +2,7 @@
 
 declare(strict_types=1);
 
-namespace Drupal\layout_builder_fieldblock_test\Plugin\Block;
+namespace Drupal\layout_builder_field_block_test\Plugin\Block;
 
 use Drupal\Core\Block\Attribute\Block;
 use Drupal\layout_builder\Plugin\Block\FieldBlock as LayoutBuilderFieldBlock;
diff --git a/core/modules/layout_builder/tests/modules/layout_builder_fieldblock_test/layout_builder_fieldblock_test.services.yml b/core/modules/layout_builder/tests/modules/layout_builder_fieldblock_test/layout_builder_fieldblock_test.services.yml
deleted file mode 100644
index ed7b1f92cfe839ff26e962d775a21647d1e582b8..0000000000000000000000000000000000000000
--- a/core/modules/layout_builder/tests/modules/layout_builder_fieldblock_test/layout_builder_fieldblock_test.services.yml
+++ /dev/null
@@ -1,5 +0,0 @@
-services:
-  layout_builder_fieldblock_test.fake_view_mode_context:
-    class: Drupal\layout_builder_fieldblock_test\ContextProvider\FakeViewModeContext
-    tags:
-      - { name: 'context_provider' }
diff --git a/core/modules/layout_builder/tests/src/FunctionalJavascript/FieldBlockTest.php b/core/modules/layout_builder/tests/src/FunctionalJavascript/FieldBlockTest.php
index 58053f8ba3fcfd116066d1284ff4e815cdef1537..75fdf40097c59b791061cb836704256c7f46fafc 100644
--- a/core/modules/layout_builder/tests/src/FunctionalJavascript/FieldBlockTest.php
+++ b/core/modules/layout_builder/tests/src/FunctionalJavascript/FieldBlockTest.php
@@ -26,8 +26,8 @@ class FieldBlockTest extends WebDriverTestBase {
     'datetime',
     'layout_builder',
     'user',
-    // See \Drupal\layout_builder_fieldblock_test\Plugin\Block\FieldBlock.
-    'layout_builder_fieldblock_test',
+    // See \Drupal\layout_builder_field_block_test\Plugin\Block\FieldBlock.
+    'layout_builder_field_block_test',
     'layout_builder_expose_all_field_blocks',
   ];
 
diff --git a/core/modules/node/config/schema/node.schema.yml b/core/modules/node/config/schema/node.schema.yml
index 08fe92cc401e4ec5d4996362302c2f670866fedc..9e9f93022b9f9ac8763023a876ea1a983ecad9b5 100644
--- a/core/modules/node/config/schema/node.schema.yml
+++ b/core/modules/node/config/schema/node.schema.yml
@@ -1,5 +1,4 @@
 # Schema for the configuration files of the node module.
-
 node.settings:
   type: config_object
   label: 'Node settings'
diff --git a/core/modules/node/src/NodeViewsData.php b/core/modules/node/src/NodeViewsData.php
index 2f3a837277506eb538ed02c87b127a55cfab2bb7..a6474b3505e477d8f174b70e263c87663ea425a3 100644
--- a/core/modules/node/src/NodeViewsData.php
+++ b/core/modules/node/src/NodeViewsData.php
@@ -4,6 +4,8 @@
 
 use Drupal\views\EntityViewsData;
 
+// cspell:ignore fulldate
+
 /**
  * Provides the views data for the node entity type.
  */
diff --git a/core/modules/node/src/Plugin/views/field/Node.php b/core/modules/node/src/Plugin/views/field/Node.php
index 1b11a4ff4b78ba8ff0209645bede481d26b509c4..8c04e94232ff03d8dfa3f4de91d9e2ecc21c38ee 100644
--- a/core/modules/node/src/Plugin/views/field/Node.php
+++ b/core/modules/node/src/Plugin/views/field/Node.php
@@ -28,7 +28,7 @@ class Node extends FieldPluginBase {
   public function init(ViewExecutable $view, DisplayPluginBase $display, ?array &$options = NULL) {
     parent::init($view, $display, $options);
 
-    // Don't add the additional fields to groupby
+    // Don't add the additional fields to group by.
     if (!empty($this->options['link_to_node'])) {
       $this->additional_fields['nid'] = ['table' => 'node_field_data', 'field' => 'nid'];
     }
diff --git a/core/modules/taxonomy/config/schema/taxonomy.views.schema.yml b/core/modules/taxonomy/config/schema/taxonomy.views.schema.yml
index 9ec97581852b9adf8218f1e2f7800a3347ae5dcd..c328514c9bc3b49a8114229d498b0c2744d4a25e 100644
--- a/core/modules/taxonomy/config/schema/taxonomy.views.schema.yml
+++ b/core/modules/taxonomy/config/schema/taxonomy.views.schema.yml
@@ -1,4 +1,5 @@
 # Schema for the views plugins of the Taxonomy module.
+# cspell:ignore anyall
 
 views.argument.taxonomy_index_tid:
   type: views.argument.many_to_one
diff --git a/core/modules/taxonomy/src/Plugin/views/argument_default/Tid.php b/core/modules/taxonomy/src/Plugin/views/argument_default/Tid.php
index 6b6188a5efffad95d4f014b4a634382c9c9f2263..f44887e9863afe706f226b03bab0c8ad0fc335a0 100644
--- a/core/modules/taxonomy/src/Plugin/views/argument_default/Tid.php
+++ b/core/modules/taxonomy/src/Plugin/views/argument_default/Tid.php
@@ -14,6 +14,8 @@
 use Symfony\Component\DependencyInjection\ContainerInterface;
 use Drupal\taxonomy\VocabularyStorageInterface;
 
+// cspell:ignore anyall
+
 /**
  * Taxonomy tid default argument.
  */
diff --git a/core/modules/taxonomy/src/TermViewsData.php b/core/modules/taxonomy/src/TermViewsData.php
index b997aecc3b3e5661a2a4f445001bf702bef0b989..399ccc16be56143d83cf4b8ec96b8400c3b8eea2 100644
--- a/core/modules/taxonomy/src/TermViewsData.php
+++ b/core/modules/taxonomy/src/TermViewsData.php
@@ -4,6 +4,8 @@
 
 use Drupal\views\EntityViewsData;
 
+// cspell:ignore fulldate
+
 /**
  * Provides the views data for the taxonomy entity type.
  */
diff --git a/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.taxonomy_default_argument_test.yml b/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.taxonomy_default_argument_test.yml
index 0c155b2ee50f82636a864f1a50224142f78b9caa..74918323adc93ac8548ae2c7dff9492423297a12 100644
--- a/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.taxonomy_default_argument_test.yml
+++ b/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.taxonomy_default_argument_test.yml
@@ -1,3 +1,4 @@
+# cspell:ignore anyall
 langcode: en
 status: true
 dependencies:
diff --git a/core/modules/user/src/UserViewsData.php b/core/modules/user/src/UserViewsData.php
index 7581d67b67cbb2544651d809814067a1a2749d41..83fac20e279c0c8f7d4169d3a45e198bb3e82bf7 100644
--- a/core/modules/user/src/UserViewsData.php
+++ b/core/modules/user/src/UserViewsData.php
@@ -4,6 +4,8 @@
 
 use Drupal\views\EntityViewsData;
 
+// cspell:ignore fulldate
+
 /**
  * Provides the views data for the user entity type.
  */
diff --git a/core/modules/views/config/schema/views.argument.schema.yml b/core/modules/views/config/schema/views.argument.schema.yml
index 5c1e3afae68dc06faa09ff11d8641da43fe61436..faacc01d5520f984a3039b9d0ea881cc1667f1e4 100644
--- a/core/modules/views/config/schema/views.argument.schema.yml
+++ b/core/modules/views/config/schema/views.argument.schema.yml
@@ -1,5 +1,5 @@
 # Schema for the views argument plugins.
-
+# cspell:ignore fulldate groupby
 views.argument.*:
   type: views_argument
   label: 'Default argument'
diff --git a/core/modules/views/config/schema/views.filter.schema.yml b/core/modules/views/config/schema/views.filter.schema.yml
index 6eb22b82f996175cba2ba2c1aad00048cc11019b..e908a0a1e055f43bfd2d5cce3b953f907478d01e 100644
--- a/core/modules/views/config/schema/views.filter.schema.yml
+++ b/core/modules/views/config/schema/views.filter.schema.yml
@@ -1,5 +1,5 @@
 # Schema for the views filter plugins.
-
+# cspell:ignore groupby
 views.filter.*:
   type: views_filter
   label: 'Default filter'
diff --git a/core/modules/views/src/Plugin/views/HandlerBase.php b/core/modules/views/src/Plugin/views/HandlerBase.php
index 00f0e18def02d25a7ac836e040d40daefe15c473..7ae13165e9ac7d85180e676fce1ac2f0c9329b13 100644
--- a/core/modules/views/src/Plugin/views/HandlerBase.php
+++ b/core/modules/views/src/Plugin/views/HandlerBase.php
@@ -325,7 +325,7 @@ public function setModuleHandler(ModuleHandlerInterface $module_handler) {
   }
 
   /**
-   * Provides the handler some groupby.
+   * Provides the handler some group by.
    */
   public function usesGroupBy() {
     return TRUE;
diff --git a/core/modules/views/src/Plugin/views/argument/FullDate.php b/core/modules/views/src/Plugin/views/argument/FullDate.php
index b79acf02132d595341680f15d10d2763de561f7e..356fb9739a2f544cba68d4329a70d0de8d5c5bac 100644
--- a/core/modules/views/src/Plugin/views/argument/FullDate.php
+++ b/core/modules/views/src/Plugin/views/argument/FullDate.php
@@ -4,6 +4,8 @@
 
 use Drupal\views\Attribute\ViewsArgument;
 
+// cspell:ignore fulldate
+
 /**
  * Argument handler for a full date (CCYYMMDD)
  */
diff --git a/core/modules/views/src/Plugin/views/argument/GroupByNumeric.php b/core/modules/views/src/Plugin/views/argument/GroupByNumeric.php
index 03b4568f33aa69c6b4d7831a190ee96d82252d1c..82080346a3e8c843b0c1532db5bebcf6f36a16c0 100644
--- a/core/modules/views/src/Plugin/views/argument/GroupByNumeric.php
+++ b/core/modules/views/src/Plugin/views/argument/GroupByNumeric.php
@@ -4,6 +4,8 @@
 
 use Drupal\views\Attribute\ViewsArgument;
 
+// cspell:ignore groupby
+
 /**
  * Simple handler for arguments using group by.
  *
diff --git a/core/modules/views/src/Plugin/views/display/DisplayPluginInterface.php b/core/modules/views/src/Plugin/views/display/DisplayPluginInterface.php
index 11b0df989119f867f70540cb7e4c0116e7f8d5a9..54dc089f9f01309934ada09db5af94a7b66844a0 100644
--- a/core/modules/views/src/Plugin/views/display/DisplayPluginInterface.php
+++ b/core/modules/views/src/Plugin/views/display/DisplayPluginInterface.php
@@ -121,7 +121,7 @@ public function usesMore();
   public function isMoreEnabled();
 
   /**
-   * Does the display have groupby enabled?
+   * Does the display have group by enabled?
    */
   public function useGroupBy();
 
diff --git a/core/modules/views/src/Plugin/views/field/EntityField.php b/core/modules/views/src/Plugin/views/field/EntityField.php
index 4c29b9a178e3a7f4f907daf68532bce85e68e2d7..ec500749ff76995e7d4fc4c80c31f0f64c396338 100644
--- a/core/modules/views/src/Plugin/views/field/EntityField.php
+++ b/core/modules/views/src/Plugin/views/field/EntityField.php
@@ -254,7 +254,7 @@ public function access(AccountInterface $account) {
    * By default, all needed data is taken from entities loaded by the query
    * plugin. Columns are added only if they are used in groupings.
    */
-  public function query($use_groupby = FALSE) {
+  public function query($use_group_by = FALSE) {
     $fields = $this->additional_fields;
     // No need to add the entity type.
     $entity_type_key = array_search('entity_type', $fields);
@@ -262,7 +262,7 @@ public function query($use_groupby = FALSE) {
       unset($fields[$entity_type_key]);
     }
 
-    if ($use_groupby) {
+    if ($use_group_by) {
       // Add the fields that we're actually grouping on.
       $options = [];
       if ($this->options['group_column'] != 'entity_id') {
@@ -283,7 +283,7 @@ public function query($use_groupby = FALSE) {
     }
 
     // Add additional fields (and the table join itself) if needed.
-    if ($this->add_field_table($use_groupby)) {
+    if ($this->add_field_table($use_group_by)) {
       $this->ensureMyTable();
       $this->addAdditionalFields($fields);
     }
@@ -295,9 +295,9 @@ public function query($use_groupby = FALSE) {
   /**
    * Determine if the field table should be added to the query.
    */
-  public function add_field_table($use_groupby) {
+  public function add_field_table($use_group_by) {
     // Grouping is enabled.
-    if ($use_groupby) {
+    if ($use_group_by) {
       return TRUE;
     }
     // This a multiple value field, but "group multiple values" is not checked.
@@ -679,7 +679,7 @@ public function multiple_options_form(&$form, FormStateInterface $form_state) {
   }
 
   /**
-   * Extend the groupby form with group columns.
+   * Extend the group by form with group columns.
    */
   public function buildGroupByForm(&$form, FormStateInterface $form_state) {
     parent::buildGroupByForm($form, $form_state);
diff --git a/core/modules/views/src/Plugin/views/filter/GroupByNumeric.php b/core/modules/views/src/Plugin/views/filter/GroupByNumeric.php
index d05c8f7d6b3dd2689cc74850922cba74963bedb8..8c3e38c1de927920231a269c857071b84742999a 100644
--- a/core/modules/views/src/Plugin/views/filter/GroupByNumeric.php
+++ b/core/modules/views/src/Plugin/views/filter/GroupByNumeric.php
@@ -4,6 +4,8 @@
 
 use Drupal\views\Attribute\ViewsFilter;
 
+// cspell:ignore groupby
+
 /**
  * Simple filter to handle greater than/less than filters.
  *
diff --git a/core/modules/views/src/Plugin/views/query/Sql.php b/core/modules/views/src/Plugin/views/query/Sql.php
index 7e5d216b148484e7bbc02820e11b746df0ab2727..187d31f236ac188b384c124ab25327231d1cb3f3 100644
--- a/core/modules/views/src/Plugin/views/query/Sql.php
+++ b/core/modules/views/src/Plugin/views/query/Sql.php
@@ -19,6 +19,8 @@
 use Drupal\views\Views;
 use Symfony\Component\DependencyInjection\ContainerInterface;
 
+// cspell: ignore groupby
+
 /**
  * Views query plugin for an SQL query.
  *
diff --git a/core/modules/views/src/Plugin/views/sort/GroupByNumeric.php b/core/modules/views/src/Plugin/views/sort/GroupByNumeric.php
index 5a16857a76f2722ee06ea092711803fedba193bc..1871cf83ea3c528ed4a40549a9337eba08f0d6ac 100644
--- a/core/modules/views/src/Plugin/views/sort/GroupByNumeric.php
+++ b/core/modules/views/src/Plugin/views/sort/GroupByNumeric.php
@@ -8,6 +8,8 @@
 use Drupal\views\ViewExecutable;
 use Drupal\views\Views;
 
+// cspell:ignore groupby
+
 /**
  * Handler for GROUP BY on simple numeric fields.
  */
diff --git a/core/modules/views/src/Plugin/views/style/StylePluginBase.php b/core/modules/views/src/Plugin/views/style/StylePluginBase.php
index d73136e7811460b574c54ba786da3d5643405f76..dca9bd27bf9cef4af91daaac158863e15afbab18 100644
--- a/core/modules/views/src/Plugin/views/style/StylePluginBase.php
+++ b/core/modules/views/src/Plugin/views/style/StylePluginBase.php
@@ -366,7 +366,7 @@ public function buildOptionsForm(&$form, FormStateInterface $form_state) {
       $form['uses_fields'] = [
         '#type' => 'checkbox',
         '#title' => $this->t('Force using fields'),
-        '#description' => $this->t('If neither the row nor the style plugin supports fields, this field allows to enable them, so you can for example use groupby.'),
+        '#description' => $this->t('If neither the row nor the style plugin supports fields, this field allows to enable them, so you can for example use group by.'),
         '#default_value' => $this->options['uses_fields'],
       ];
     }
diff --git a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_argument_date.yml b/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_argument_date.yml
index fda842ad0d9141cbb75a4a70767a65de20f39770..1bebef66c4087dfaeda2dc718320afbbf253a349 100644
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_argument_date.yml
+++ b/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_argument_date.yml
@@ -1,3 +1,4 @@
+# cspell:ignore fulldate
 langcode: en
 status: true
 dependencies: {  }
diff --git a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_destroy.yml b/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_destroy.yml
index 2b5be0e166b384fd3d459c3e5138bef64c410d75..05823d47016047cea4c81db91d574c89868e8bb5 100644
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_destroy.yml
+++ b/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_destroy.yml
@@ -1,3 +1,4 @@
+# cspell:ignore fulldate
 langcode: en
 status: true
 dependencies:
diff --git a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_views_groupby_save.yml b/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_views_group_by_save.yml
similarity index 90%
rename from core/modules/views/tests/modules/views_test_config/test_views/views.view.test_views_groupby_save.yml
rename to core/modules/views/tests/modules/views_test_config/test_views/views.view.test_views_group_by_save.yml
index 1e75c3f22610b917bc30526de7d005a44ab82d42..30f3bbfd66c175dbdea34a93ac372bcca53b87e5 100644
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_views_groupby_save.yml
+++ b/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_views_group_by_save.yml
@@ -1,8 +1,8 @@
 langcode: en
 status: true
 dependencies: {  }
-id: test_views_groupby_save
-label: test_views_groupby_save
+id: test_views_group_by_save
+label: test_views_group_by_save
 module: views
 description: ''
 tag: ''
diff --git a/core/modules/views/tests/src/Kernel/Handler/ArgumentDateTest.php b/core/modules/views/tests/src/Kernel/Handler/ArgumentDateTest.php
index 53b14c8b47b641603895af47b34ff03ac4fdd7a7..e5003d593772ad180f89a2424369b306897c7cc0 100644
--- a/core/modules/views/tests/src/Kernel/Handler/ArgumentDateTest.php
+++ b/core/modules/views/tests/src/Kernel/Handler/ArgumentDateTest.php
@@ -4,6 +4,8 @@
 
 namespace Drupal\Tests\views\Kernel\Handler;
 
+// cspell:ignore fulldate
+
 use Drupal\Tests\views\Kernel\ViewsKernelTestBase;
 use Drupal\views\Views;
 
diff --git a/core/modules/views/tests/src/Kernel/Plugin/StyleTest.php b/core/modules/views/tests/src/Kernel/Plugin/StyleTest.php
index a88ee3ae0ed6e881db9ae6e60b35aeec2ff16afb..547fad4ca7c13b49b9b6f707b0d7a4f217582c78 100644
--- a/core/modules/views/tests/src/Kernel/Plugin/StyleTest.php
+++ b/core/modules/views/tests/src/Kernel/Plugin/StyleTest.php
@@ -129,7 +129,7 @@ protected function doTestGrouping($stripped = FALSE) {
     ];
     $view->displayHandlers->get('default')->overrideOption('fields', $fields);
 
-    // Now run the query and groupby the result.
+    // Now run the query and group by the result.
     $this->executeView($view);
 
     $expected = [];
diff --git a/core/modules/views_ui/tests/src/Functional/FieldUITest.php b/core/modules/views_ui/tests/src/Functional/FieldUITest.php
index cd8a199d18af67446be4af1a75723654a7b43873..be8228294797b30b6db211c23fd8339ec75be126 100644
--- a/core/modules/views_ui/tests/src/Functional/FieldUITest.php
+++ b/core/modules/views_ui/tests/src/Functional/FieldUITest.php
@@ -63,8 +63,8 @@ public function testFieldUI(): void {
     $this->assertSession()->elementNotExists('xpath', '//details[@id="edit-options-more"]');
 
     // Ensure that dialog titles are not escaped.
-    $edit_groupby_url = 'admin/structure/views/nojs/handler/test_view/default/field/name';
-    $this->assertSession()->linkByHrefNotExists($edit_groupby_url, 0, 'No aggregation link found.');
+    $edit_group_by_url = 'admin/structure/views/nojs/handler/test_view/default/field/name';
+    $this->assertSession()->linkByHrefNotExists($edit_group_by_url, 0, 'No aggregation link found.');
 
     // Enable aggregation on the view.
     $edit = [
@@ -73,7 +73,7 @@ public function testFieldUI(): void {
     $this->drupalGet('/admin/structure/views/nojs/display/test_view/default/group_by');
     $this->submitForm($edit, 'Apply');
 
-    $this->assertSession()->linkByHrefExists($edit_groupby_url, 0, 'Aggregation link found.');
+    $this->assertSession()->linkByHrefExists($edit_group_by_url, 0, 'Aggregation link found.');
 
     $edit_handler_url = '/admin/structure/views/ajax/handler-group/test_view/default/field/name';
     $this->drupalGet($edit_handler_url);
diff --git a/core/modules/views_ui/tests/src/Functional/GroupByTest.php b/core/modules/views_ui/tests/src/Functional/GroupByTest.php
index 69210693027895c0e063bcd668092fb469c6a137..1c596ad16cb358c0ec18261d8391eaa10f0c1d9d 100644
--- a/core/modules/views_ui/tests/src/Functional/GroupByTest.php
+++ b/core/modules/views_ui/tests/src/Functional/GroupByTest.php
@@ -16,7 +16,7 @@ class GroupByTest extends UITestBase {
    *
    * @var array
    */
-  public static $testViews = ['test_views_groupby_save'];
+  public static $testViews = ['test_views_group_by_save'];
 
   /**
    * {@inheritdoc}
@@ -29,31 +29,31 @@ class GroupByTest extends UITestBase {
    * @todo This should check the change of the settings as well.
    */
   public function testGroupBySave(): void {
-    $this->drupalGet('admin/structure/views/view/test_views_groupby_save/edit');
+    $this->drupalGet('admin/structure/views/view/test_views_group_by_save/edit');
 
-    $edit_groupby_url = 'admin/structure/views/nojs/handler-group/test_views_groupby_save/default/field/id';
-    $this->assertSession()->linkByHrefNotExists($edit_groupby_url, 0, 'No aggregation link found.');
+    $edit_group_by_url = 'admin/structure/views/nojs/handler-group/test_views_group_by_save/default/field/id';
+    $this->assertSession()->linkByHrefNotExists($edit_group_by_url, 0, 'No aggregation link found.');
 
     // Enable aggregation on the view.
     $edit = [
       'group_by' => TRUE,
     ];
-    $this->drupalGet('admin/structure/views/nojs/display/test_views_groupby_save/default/group_by');
+    $this->drupalGet('admin/structure/views/nojs/display/test_views_group_by_save/default/group_by');
     $this->submitForm($edit, 'Apply');
 
-    $this->assertSession()->linkByHrefExists($edit_groupby_url, 0, 'Aggregation link found.');
+    $this->assertSession()->linkByHrefExists($edit_group_by_url, 0, 'Aggregation link found.');
 
-    // Change the groupby type in the UI.
-    $this->drupalGet($edit_groupby_url);
+    // Change the group by type in the UI.
+    $this->drupalGet($edit_group_by_url);
     $this->submitForm(['options[group_type]' => 'count'], 'Apply');
     $this->assertSession()->linkExists('COUNT(Views test: ID)', 0, 'The count setting is displayed in the UI');
 
     $this->submitForm([], 'Save');
 
-    $view = $this->container->get('entity_type.manager')->getStorage('view')->load('test_views_groupby_save');
+    $view = $this->container->get('entity_type.manager')->getStorage('view')->load('test_views_group_by_save');
     $display = $view->getDisplay('default');
-    $this->assertTrue($display['display_options']['group_by'], 'The groupby setting was saved on the view.');
-    $this->assertEquals('count', $display['display_options']['fields']['id']['group_type'], 'Count groupby_type was saved on the view.');
+    $this->assertTrue($display['display_options']['group_by'], 'The group by setting was saved on the view.');
+    $this->assertEquals('count', $display['display_options']['fields']['id']['group_type'], 'Count group_by_type was saved on the view.');
   }
 
 }
diff --git a/core/modules/workspaces/src/ViewsQueryAlter.php b/core/modules/workspaces/src/ViewsQueryAlter.php
index 4cfb5d78dad3e6582a811d5991351c72995f862f..2a797543835667bc0d1b23a3bcc1934a2ad7d06e 100644
--- a/core/modules/workspaces/src/ViewsQueryAlter.php
+++ b/core/modules/workspaces/src/ViewsQueryAlter.php
@@ -284,7 +284,7 @@ protected function alterQueryForEntityType(Sql $query, EntityTypeInterface $enti
       }
     }
 
-    // @todo Handle $query->orderby, $query->groupby, $query->having and
+    // @todo Handle $query->orderby, $query->groupBy, $query->having and
     //   $query->count_field in https://www.drupal.org/node/2968165.
   }
 
diff --git a/core/profiles/demo_umami/config/install/core.entity_view_display.media.audio.default.yml b/core/profiles/demo_umami/config/install/core.entity_view_display.media.audio.default.yml
index 423be99322114a9ec431769ed9e440de6f1cc04c..e8f21625d8dd5b99a63ef59bbf73b79f0233d890 100644
--- a/core/profiles/demo_umami/config/install/core.entity_view_display.media.audio.default.yml
+++ b/core/profiles/demo_umami/config/install/core.entity_view_display.media.audio.default.yml
@@ -1,3 +1,4 @@
+# cspell:ignore autoplay
 langcode: en
 status: true
 dependencies:
diff --git a/core/profiles/demo_umami/config/install/core.entity_view_display.media.video.default.yml b/core/profiles/demo_umami/config/install/core.entity_view_display.media.video.default.yml
index c3bcba99b6e5b7b4a10203b453c4edefd7867aaa..b8ea26fd67d14ddb2d3169a422fe08ab0518376b 100644
--- a/core/profiles/demo_umami/config/install/core.entity_view_display.media.video.default.yml
+++ b/core/profiles/demo_umami/config/install/core.entity_view_display.media.video.default.yml
@@ -1,3 +1,4 @@
+# cspell:ignore autoplay
 langcode: en
 status: true
 dependencies:
diff --git a/core/profiles/demo_umami/config/install/views.view.related_recipes.yml b/core/profiles/demo_umami/config/install/views.view.related_recipes.yml
index 8ee77d538ede04447203f0ffd5547c41a3eda729..0083d9054cb4cacc408b01ec9600794104435741 100644
--- a/core/profiles/demo_umami/config/install/views.view.related_recipes.yml
+++ b/core/profiles/demo_umami/config/install/views.view.related_recipes.yml
@@ -1,3 +1,4 @@
+# cspell:ignore anyall
 langcode: en
 status: true
 dependencies:
diff --git a/core/profiles/standard/config/optional/core.entity_view_display.media.audio.default.yml b/core/profiles/standard/config/optional/core.entity_view_display.media.audio.default.yml
index 2956f6913195ea52a6b768979df7ec400235b4f7..1e638c21bf90bbaf9693e29601d205ea58a6a4b2 100644
--- a/core/profiles/standard/config/optional/core.entity_view_display.media.audio.default.yml
+++ b/core/profiles/standard/config/optional/core.entity_view_display.media.audio.default.yml
@@ -1,3 +1,4 @@
+# cspell:ignore autoplay
 langcode: en
 status: true
 dependencies:
diff --git a/core/profiles/standard/config/optional/core.entity_view_display.media.video.default.yml b/core/profiles/standard/config/optional/core.entity_view_display.media.video.default.yml
index 3c26f17aae3e9a4dd263a008233424f1bd06ad13..5ef0df791b61088cf011ab4d91905bbb46ca5128 100644
--- a/core/profiles/standard/config/optional/core.entity_view_display.media.video.default.yml
+++ b/core/profiles/standard/config/optional/core.entity_view_display.media.video.default.yml
@@ -1,3 +1,4 @@
+# cspell:ignore autoplay
 langcode: en
 status: true
 dependencies:
diff --git a/core/recipes/audio_media_type/config/core.entity_view_display.media.audio.default.yml b/core/recipes/audio_media_type/config/core.entity_view_display.media.audio.default.yml
index 2956f6913195ea52a6b768979df7ec400235b4f7..1e638c21bf90bbaf9693e29601d205ea58a6a4b2 100644
--- a/core/recipes/audio_media_type/config/core.entity_view_display.media.audio.default.yml
+++ b/core/recipes/audio_media_type/config/core.entity_view_display.media.audio.default.yml
@@ -1,3 +1,4 @@
+# cspell:ignore autoplay
 langcode: en
 status: true
 dependencies:
diff --git a/core/recipes/local_video_media_type/config/core.entity_view_display.media.video.default.yml b/core/recipes/local_video_media_type/config/core.entity_view_display.media.video.default.yml
index 3c26f17aae3e9a4dd263a008233424f1bd06ad13..5ef0df791b61088cf011ab4d91905bbb46ca5128 100644
--- a/core/recipes/local_video_media_type/config/core.entity_view_display.media.video.default.yml
+++ b/core/recipes/local_video_media_type/config/core.entity_view_display.media.video.default.yml
@@ -1,3 +1,4 @@
+# cspell:ignore autoplay
 langcode: en
 status: true
 dependencies:
diff --git a/core/tests/Drupal/KernelTests/Core/Entity/EntityQueryAggregateTest.php b/core/tests/Drupal/KernelTests/Core/Entity/EntityQueryAggregateTest.php
index eb78d6f6b3e78d919c58d16c6c99d92f2e56f933..38fde0dc5a0d89aa359aed57ffda8022f8f5ba5d 100644
--- a/core/tests/Drupal/KernelTests/Core/Entity/EntityQueryAggregateTest.php
+++ b/core/tests/Drupal/KernelTests/Core/Entity/EntityQueryAggregateTest.php
@@ -114,7 +114,7 @@ protected function setUp(): void {
    * Tests aggregation support.
    */
   public function testAggregation(): void {
-    // Apply a simple groupby.
+    // Apply a simple group by.
     $this->queryResult = $this->entityStorage->getAggregateQuery()
       ->accessCheck(FALSE)
       ->groupBy('user_id')
@@ -146,7 +146,7 @@ public function testAggregation(): void {
       $this->assertEquals($expected, $this->queryResult);
     }
 
-    // Apply aggregation and groupby on the same query.
+    // Apply aggregation and group by on the same query.
     $this->queryResult = $this->entityStorage->getAggregateQuery()
       ->accessCheck(FALSE)
       ->aggregate('id', 'COUNT')
@@ -184,7 +184,7 @@ public function testAggregation(): void {
       ->execute();
     $this->assertResults([['id_count' => 6]]);
 
-    // Apply aggregation, a groupby and a condition which matches partially via
+    // Apply aggregation, a group by and a condition which matches partially via
     // the operator '='.
     $this->queryResult = $this->entityStorage->getAggregateQuery()
       ->accessCheck(FALSE)
@@ -194,7 +194,7 @@ public function testAggregation(): void {
       ->execute();
     $this->assertResults([['id_count' => 2, 'user_id' => 3]]);
 
-    // Apply aggregation, a groupby and a condition which matches partially via
+    // Apply aggregation, a group by and a condition which matches partially via
     // the operator '>'.
     $this->queryResult = $this->entityStorage->getAggregateQuery()
       ->accessCheck(FALSE)
@@ -223,7 +223,7 @@ public function testAggregation(): void {
       ->execute();
     $this->assertSortedResults([['id_count' => 6]]);
 
-    // Apply aggregation, groupby and a sort descending.
+    // Apply aggregation, group by and a sort descending.
     $this->queryResult = $this->entityStorage->getAggregateQuery()
       ->accessCheck(FALSE)
       ->aggregate('id', 'COUNT')
@@ -236,7 +236,7 @@ public function testAggregation(): void {
       ['user_id' => 1, 'id_count' => 1],
     ]);
 
-    // Apply aggregation, groupby and a sort ascending.
+    // Apply aggregation, group by and a sort ascending.
     $this->queryResult = $this->entityStorage->getAggregateQuery()
       ->accessCheck(FALSE)
       ->aggregate('id', 'COUNT')
@@ -249,7 +249,7 @@ public function testAggregation(): void {
       ['user_id' => 2, 'id_count' => 3],
     ]);
 
-    // Apply aggregation, groupby, an aggregation condition and a sort with the
+    // Apply aggregation, group by, an aggregation condition and a sort with the
     // operator '='.
     $this->queryResult = $this->entityStorage->getAggregateQuery()
       ->accessCheck(FALSE)
@@ -260,7 +260,7 @@ public function testAggregation(): void {
       ->execute();
     $this->assertSortedResults([['id_count' => 2, 'user_id' => 3]]);
 
-    // Apply aggregation, groupby, an aggregation condition and a sort with the
+    // Apply aggregation, group by, an aggregation condition and a sort with the
     // operator '<' and order ASC.
     $this->queryResult = $this->entityStorage->getAggregateQuery()
       ->accessCheck(FALSE)
@@ -274,7 +274,7 @@ public function testAggregation(): void {
       ['id_count' => 2, 'user_id' => 3],
     ]);
 
-    // Apply aggregation, groupby, an aggregation condition and a sort with the
+    // Apply aggregation, group by, an aggregation condition and a sort with the
     // operator '<' and order DESC.
     $this->queryResult = $this->entityStorage->getAggregateQuery()
       ->accessCheck(FALSE)
@@ -288,7 +288,7 @@ public function testAggregation(): void {
       ['id_count' => 1, 'user_id' => 1],
     ]);
 
-    // Test aggregation/groupby support for fieldapi fields.
+    // Test aggregation/group by support for fieldapi fields.
 
     // Just group by a fieldapi field.
     $this->queryResult = $this->entityStorage->getAggregateQuery()
@@ -477,7 +477,7 @@ public function testAggregation(): void {
     ]);
 
     // Group by a normal property and aggregate a fieldapi field and sort by the
-    // groupby field.
+    // group by field.
     $this->queryResult = $this->entityStorage->getAggregateQuery()
       ->accessCheck(FALSE)
       ->aggregate('field_test_1', 'COUNT')
@@ -537,7 +537,7 @@ public function testAggregation(): void {
       ['user_id' => 2, 'field_test_1_count' => 3],
     ]);
 
-    // Group by and aggregate by fieldapi field, and sort by the groupby field.
+    // Group by and aggregate by fieldapi field, and sort by the group by field.
     $this->queryResult = $this->entityStorage->getAggregateQuery()
       ->accessCheck(FALSE)
       ->groupBy('field_test_1')
diff --git a/core/modules/views/tests/src/Kernel/QueryGroupByTest.php b/core/modules/views/tests/src/Kernel/QueryGroupByTest.php
index a28114501753280e7ed4cd1384e7428fa448166d..c5e6aa75075ec13a1b3c094ac237e186955592da 100644
--- a/core/modules/views/tests/src/Kernel/QueryGroupByTest.php
+++ b/core/modules/views/tests/src/Kernel/QueryGroupByTest.php
@@ -131,8 +131,8 @@ public function groupByTestHelper($aggregation_function, $values) {
       $results[$item->entity_test_name] = $item->id;
     }
     $aggregation_function ??= 'NULL';
-    $this->assertEquals($values[0], $results['name1'], "Aggregation with $aggregation_function and groupby name: name1 returned the expected amount of results");
-    $this->assertEquals($values[1], $results['name2'], "Aggregation with $aggregation_function and groupby name: name2 returned the expected amount of results");
+    $this->assertEquals($values[0], $results['name1'], "Aggregation with $aggregation_function and group by name: name1 returned the expected amount of results");
+    $this->assertEquals($values[1], $results['name2'], "Aggregation with $aggregation_function and group by name: name2 returned the expected amount of results");
   }
 
   /**
@@ -200,7 +200,7 @@ public function testGroupByNone(): void {
   }
 
   /**
    * Tests groupby with filters.
    */
   public function testGroupByCountOnlyFilters(): void {
     // Check if GROUP BY and HAVING are included when a view
@@ -314,7 +314,7 @@ public function testGroupByFieldWithCardinality(): void {
   }
 
   /**
    * Tests groupby with a non-existent field on some bundle.
    */
   public function testGroupByWithFieldsNotExistingOnBundle(): void {
     $field_storage = FieldStorageConfig::create([
@@ -200,7 +200,7 @@ public function testGroupByNone(): void {
 
   /**
-   * Tests groupby with filters.
+   * Tests group by with filters.
    */
   public function testGroupByCountOnlyFilters(): void {
@@ -314,7 +314,7 @@ public function testGroupByFieldWithCardinality(): void {
 
   /**
-   * Tests groupby with a non-existent field on some bundle.
+   * Tests group by with a non-existent field on some bundle.
    */
   public function testGroupByWithFieldsNotExistingOnBundle(): void {